import csv
import os
import pytest

from wooify.wooifier import Wooifier
from wooify.adapters.adapter import Adapter
from wooify.constants import (ALLOWED_HTML_TAGS, HTML_FIELDS,
                              WOO_IMP_EXP_PRODUCT_FIELDS)

def test_init():
    wooifier = Wooifier(Adapter)
    assert wooifier.adapter_cls == Adapter

def test_wooify(monkeypatch, tmpdir):
    def mockparse(self, test_file):
        products = [{
            'sku': 'test1',
            'name': 'Test 1',
        }]
        for p in products:
            product = dict(WOO_IMP_EXP_PRODUCT_FIELDS)
            product.update({'SKU': p['sku'], 'Product Name': p['name']})
            self.products.append(product)
    monkeypatch.setattr(Adapter, 'parse', mockparse)
    wooifier = Wooifier(Adapter)
    in_file = tmpdir.join("input.csv")
    products_file = tmpdir.join("products.csv")
    categories_file = tmpdir.join("categories.csv")
    wooifier.wooify(in_file, products_file.strpath, categories_file.strpath)
    csv_reader = csv.DictReader(products_file.open())
    for row in csv_reader:
        assert row['SKU'] == 'test1'
        assert row['Product Name'] == 'Test 1'
