#!/usr/bin/env python
"""
Prepare eCommerce product data for import into the "Woo Import Export" \
WordPress plugin.

Usage: {0} adapter input_file

    adapter: an import adapter
    input_file: the source file you want to convert

Available import adapters: ecwid, dpsounds

Output will be written to:

    woocommerce_products.csv
    woocommerce_categories.csv
"""

import sys
from .wooifier import Wooifier


def main():
    try:
        adapter_name = sys.argv[1]
        input_file = sys.argv[2]
    except IndexError:
        print(__doc__.format(sys.argv[0]))
        sys.exit()

    adapter_mod = __import__('wooify.adapters.{}'.format(adapter_name),
                             fromlist=['{}Adapter'.format(
                                adapter_name.title())])
    adapter_cls = getattr(adapter_mod, '{}Adapter'.format(
                                adapter_name.title()))
    wooifier = Wooifier(adapter_cls)
    wooifier.wooify(input_file,
                    'woocommerce_products.csv',
                    'woocommerce_categories.csv')
