import lxml.html.clean
from ..constants import ALLOWED_HTML_TAGS, HTML_FIELDS


class Adapter(object):
    """The base class for adapters. An adapter is a handler for
    some format wooify should support as input.
    """
    products = []
    categories = []

    def __init__(self, filename):
        self.parse(filename)

    def parse(self, filename):
        """Parse an input file."""
        raise NotImplementedError

    @property
    def clean_products(self):
        clean_products = []
        for product in self.products:
            for field in HTML_FIELDS:
                product[field] = self._clean_html(product[field])
            clean_products.append(product)
        return clean_products

    def _clean_html(self, html_string):
        """Remove all attributes from HTML string."""
        if not html_string:
            return ''
        cleaner = lxml.html.clean.Cleaner(
            allow_tags=ALLOWED_HTML_TAGS, remove_unknown_tags=False,
            page_structure=False, safe_attrs_only=True, safe_attrs=frozenset())
        return cleaner.clean_html("<div>{0}</div>".format(html_string))
